import random
from wordle_helper import valid_guess, filter_letters, score_guess

WRONG = "🟥"
CLOSE = "🟨"
CORRECT = "🟩"
WARNING = "⚠️"
MAX_GUESSES = 6
WORD_LIST_FILE = "wordle-answers-alphabetical.txt"
ALPHABET = "abcdefghijklmnopqrstufwxyz"


def load_words(filename):
    with open(filename, 'rt') as f:
        return [line.strip() for line in f]


def main():
    # Load answers
    answers = load_words(WORD_LIST_FILE)

    # Pick an answer
    answer = random.choice(answers)

    # Take guesses from the user
    alphabet = ALPHABET
    this_round = 1
    while this_round <= MAX_GUESSES:
        print(f"Guess #{this_round}")
        print(f"Unused letters: {alphabet}")
        word_guess = input("Word guess: ").strip()
        # check if guess is valid
        if not valid_guess(word_guess):
            print()
            print(f"{WARNING} Your guess must be exactly five letters long!")
            print()
            continue
        # score the guess
        score = score_guess(word_guess, answer, WRONG, CLOSE, CORRECT)
        # filter out guessed letters
        alphabet = filter_letters(word_guess, alphabet)
        print(word_guess)
        print(score)
        print()
        # check if guess is correct
        if word_guess == answer:
            print(f"Correct! ({this_round}/{MAX_GUESSES})")
            return
        this_round += 1

    print(f"You ran out of guesses! The word was: {answer}")


if __name__ == "__main__":
    main()
